@@ -1,4 +1,5 @@
 import inspect
+import os
 import os.path as op
 import time
 
@@ -7,9 +8,10 @@ import requests
 import responses
 from semantic_version import Version
 
-from ..consts import dandi_instance, known_instances
-from ..exceptions import BadCliVersionError, CliVersionTooOldError
+from .skip import mark
 from .. import __version__
+from ..consts import DandiInstance, known_instances
+from ..exceptions import BadCliVersionError, CliVersionTooOldError
 from ..utils import (
     ensure_datetime,
     ensure_strtime,
@@ -17,10 +19,10 @@ from ..utils import (
     flatten,
     flattened,
     get_instance,
+    get_mime_type,
     get_module_version,
     get_utcnow_datetime,
     is_same_time,
-    name2title,
     on_windows,
     remap_dict,
 )
@@ -156,54 +158,28 @@ def test_remap_dict(from_, revmapping, to):
     assert remap_dict(from_, revmapping) == to
 
 
-@responses.activate
-def test_get_instance_dandi():
-    responses.add(
-        responses.GET,
-        "https://dandiarchive.org/server-info",
-        json={
-            "version": "1.0.0",
-            "cli-minimal-version": "0.5.0",
-            "cli-bad-versions": [],
-            "services": {
-                "girder": {"url": "https://girder.dandi"},
-                "webui": {"url": "https://gui.dandi"},
-                "api": None,
-                "jupyterhub": {"url": "https://hub.dandi"},
-            },
-        },
-    )
-    assert get_instance("dandi") == dandi_instance(
-        metadata_version=0,
-        girder="https://girder.dandi",
-        gui="https://gui.dandi",
-        redirector="https://dandiarchive.org",
-        api=None,
-    )
+redirector_base = known_instances["dandi"].redirector
 
 
 @responses.activate
 def test_get_instance_dandi_with_api():
     responses.add(
         responses.GET,
-        "https://dandiarchive.org/server-info",
+        f"{redirector_base}/server-info",
         json={
             "version": "1.0.0",
             "cli-minimal-version": "0.5.0",
             "cli-bad-versions": [],
             "services": {
-                "girder": None,
                 "webui": {"url": "https://gui.dandi"},
                 "api": {"url": "https://api.dandi"},
                 "jupyterhub": {"url": "https://hub.dandi"},
             },
         },
     )
-    assert get_instance("dandi") == dandi_instance(
-        metadata_version=1,
-        girder=None,
+    assert get_instance("dandi") == DandiInstance(
         gui="https://gui.dandi",
-        redirector="https://dandiarchive.org",
+        redirector=redirector_base,
         api="https://api.dandi",
     )
 
@@ -218,19 +194,16 @@ def test_get_instance_url():
             "cli-minimal-version": "0.5.0",
             "cli-bad-versions": [],
             "services": {
-                "girder": {"url": "https://girder.dandi"},
                 "webui": {"url": "https://gui.dandi"},
-                "api": None,
+                "api": {"url": "https://api.dandi"},
                 "jupyterhub": {"url": "https://hub.dandi"},
             },
         },
     )
-    assert get_instance("https://example.dandi/") == dandi_instance(
-        metadata_version=0,
-        girder="https://girder.dandi",
+    assert get_instance("https://example.dandi/") == DandiInstance(
         gui="https://gui.dandi",
         redirector="https://example.dandi/",
-        api=None,
+        api="https://api.dandi",
     )
 
 
@@ -244,9 +217,8 @@ def test_get_instance_cli_version_too_old():
             "cli-minimal-version": "99.99.99",
             "cli-bad-versions": [],
             "services": {
-                "girder": {"url": "https://girder.dandi"},
                 "webui": {"url": "https://gui.dandi"},
-                "api": None,
+                "api": {"url": "https://api.dandi"},
                 "jupyterhub": {"url": "https://hub.dandi"},
             },
         },
@@ -269,9 +241,8 @@ def test_get_instance_bad_cli_version():
             "cli-minimal-version": "0.5.0",
             "cli-bad-versions": [__version__],
             "services": {
-                "girder": {"url": "https://girder.dandi"},
                 "webui": {"url": "https://gui.dandi"},
-                "api": None,
+                "api": {"url": "https://api.dandi"},
                 "jupyterhub": {"url": "https://hub.dandi"},
             },
         },
@@ -288,7 +259,7 @@ def test_get_instance_bad_cli_version():
 def test_get_instance_id_bad_response():
     responses.add(
         responses.GET,
-        "https://dandiarchive.org/server-info",
+        f"{redirector_base}/server-info",
         body="404 -- not found",
         status=404,
     )
@@ -299,11 +270,11 @@ def test_get_instance_id_bad_response():
 def test_get_instance_known_url_bad_response():
     responses.add(
         responses.GET,
-        "https://dandiarchive.org/server-info",
+        f"{redirector_base}/server-info",
         body="404 -- not found",
         status=404,
     )
-    assert get_instance("https://dandiarchive.org") is known_instances["dandi"]
+    assert get_instance(redirector_base) is known_instances["dandi"]
 
 
 @responses.activate
@@ -322,10 +293,6 @@ def test_get_instance_unknown_url_bad_response():
     )
 
 
-def test_get_instance_id_no_redirector():
-    assert get_instance("local-girder-only") is known_instances["local-girder-only"]
-
-
 @responses.activate
 def test_get_instance_bad_version_from_server():
     responses.add(
@@ -336,9 +303,8 @@ def test_get_instance_bad_version_from_server():
             "cli-minimal-version": "foobar",
             "cli-bad-versions": [],
             "services": {
-                "girder": {"url": "https://girder.dandi"},
                 "webui": {"url": "https://gui.dandi"},
-                "api": None,
+                "api": {"url": "https://api.dandi"},
                 "jupyterhub": {"url": "https://hub.dandi"},
             },
         },
@@ -354,17 +320,19 @@ def test_get_instance_bad_version_from_server():
 
 def test_get_instance_actual_dandi():
     inst = get_instance("dandi")
-    assert inst.metadata_version in (0, 1)
-    if inst.metadata_version == 0:
-        assert inst.girder is not None
-        assert inst.api is None
-    else:
-        assert inst.girder is None
-        assert inst.api is not None
+    assert inst.api is not None
 
 
+if "DANDI_REDIRECTOR_BASE" in os.environ:
+    using_docker = pytest.mark.usefixtures("local_dandi_api")
+else:
+    using_docker = mark.skipif_no_network
+
+
+@pytest.mark.redirector
+@using_docker
 def test_server_info():
-    r = requests.get(known_instances["dandi"].redirector.rstrip("/") + "/server-info")
+    r = requests.get(f"{redirector_base}/server-info")
     r.raise_for_status()
     data = r.json()
     assert "version" in data
@@ -374,26 +342,6 @@ def test_server_info():
     assert "services" in data
 
 
-@pytest.mark.parametrize(
-    "name,title",
-    [
-        ("relatedResource", "Related Resource"),
-        ("identifier", "Identifier"),
-        ("wasGeneratedBy", "Was Generated by"),
-        ("sameAs", "Same as"),
-        ("includeInCitation", "Include in Citation"),
-        ("anExtraField", "An Extra Field"),
-        ("propertyID", "Property ID"),
-        ("fieldINeed", "Field I Need"),
-        ("needsADatum", "Needs a Datum"),
-        ("contentUrl", "Content URL"),
-        ("ContactPoint", "Contact Point"),
-    ],
-)
-def test_name2title(name, title):
-    assert name2title(name) == title
-
-
 def test_get_module_version():
     import pynwb
 
@@ -403,3 +351,28 @@ def test_get_module_version():
     assert get_module_version("dandi") == __version__
     assert get_module_version("pynwb") == pynwb.__version__
     assert get_module_version("abracadabra123") is None
+
+
+@pytest.mark.parametrize(
+    "filename,mtype",
+    [
+        ("foo.txt", "text/plain"),
+        ("foo", "application/octet-stream"),
+        ("foo.gz", "application/gzip"),
+        ("foo.tar.gz", "application/gzip"),
+        ("foo.tgz", "application/gzip"),
+        ("foo.taz", "application/gzip"),
+        ("foo.svg.gz", "application/gzip"),
+        ("foo.svgz", "application/gzip"),
+        ("foo.Z", "application/x-compress"),
+        ("foo.tar.Z", "application/x-compress"),
+        ("foo.bz2", "application/x-bzip2"),
+        ("foo.tar.bz2", "application/x-bzip2"),
+        ("foo.tbz2", "application/x-bzip2"),
+        ("foo.xz", "application/x-xz"),
+        ("foo.tar.xz", "application/x-xz"),
+        ("foo.txz", "application/x-xz"),
+    ],
+)
+def test_get_mime_type(filename, mtype):
+    assert get_mime_type(filename) == mtype
